@@ -1,7 +1,7 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "feature-mode" "0.6.2"
+(define-package "feature-mode" "20251015.2134"
   "Major mode for editing Gherkin (i.e. Cucumber) user stories."
   '((emacs "28.1"))
   :url "https://github.com/freesteph/cucumber.el"
-  :commit "76c91c05d15aca7732315b46dd3dcc13ec5235fd"
-  :revdesc "76c91c05d15a")
+  :commit "8d43c37ddf986af769870da27c31c1911f35b205"
+  :revdesc "8d43c37ddf98")
