@@ -1,6 +1,6 @@
 ;;; feature-mode.el --- Major mode for editing Gherkin (i.e. Cucumber) user stories -*- lexical-binding: t -*-
-;; Package-Version: 0.6.2
-;; Package-Revision: 76c91c05d15a
+;; Package-Version: 20251015.2134
+;; Package-Revision: 8d43c37ddf98
 ;;; Author: Michael Klishin
 ;;; Maintainer: Stéphane Maniaci
 ;;; URL: https://github.com/freesteph/cucumber.el
@@ -97,6 +97,8 @@
 (require 'xref)
 (require 'rx)
 
+(autoload 'turn-on-orgtbl "org-table" nil t)
+
 (defcustom feature-cucumber-command "cucumber {options} \"{feature}\""
   "Command used to run cucumber when there is no Rakefile."
   :group 'feature-mode
@@ -185,7 +187,7 @@ The line is back-dented by `feature-indent-offset' spaces."
       (setq font-lock-variable-name-face font-lock-type-face)))
 
 (defconst feature-mode--keywords
-  '(feature background scenario scenario_outline given when then but and examples rule))
+  '(feature background scenario scenario_outline given when then but and rule examples))
 
 (defvar feature-default-language "en")
 (defvar feature-default-directory "features")
@@ -308,9 +310,10 @@ The line is back-dented by `feature-indent-offset' spaces."
 (defun feature-build-keywords-re (keywords)
   "Builds the regex to match KEYWORDS."
   (eval `(rx line-start
-             (zero-or-more space)
-             (or ,@keywords)
-             (optional ":"))))
+             (zero-or-more blank)
+             (group (or ,@keywords))
+             (optional ":")
+             word-boundary)))
 
 (defun feature--translated-keywords-for (keyword language)
   "Return the translated keywords for KEYWORD in the specified LANGUAGE."
@@ -575,7 +578,7 @@ back-dent the line by `feature-indent-offset' spaces.  On reaching column
   "Enable/disable all minor modes for feature mode."
   (turn-on-orgtbl)
   (set (make-local-variable 'electric-indent-functions)
-       (list (lambda () 'no-indent))))
+       (list (lambda (_arg) 'no-indent))))
 
 (defun feature-mode--fontlock-for-keyword (keyword language)
   "Form the font lock structure to highlight KEYWORD in LANGUAGE."
@@ -602,7 +605,8 @@ font lock table with LANGUAGE."
     (setq font-lock-defaults (list
                               (append
                                feature-mode--fontlock-static
-                               (feature-mode--fontlock-regexps language))))))
+                               (feature-mode--fontlock-regexps language))))
+    (font-lock-refresh-defaults)))
 
 ;;
 ;; Mode function
@@ -642,7 +646,7 @@ are loaded on startup.  If nil, don't load snippets.")
    The support folder contains a ruby script that takes a step as an
    argument, and outputs a list of all matching step definitions")
 
-(declare-function yas/load-directory "yasnippet" t)
+(declare-function yas-load-directory "ext:yasnippet.el" t)
 (when (and (featurep 'yasnippet)
            feature-snippet-directory
            (file-exists-p feature-snippet-directory))
